package SPVM::IO::Socket::SSL;

our $VERSION = "0.001";

1;

=head1 Name

SPVM::IO::Socket::SSL - Sockets for SSL.

=head1 Description

B<This class is highly experimental and not yet implemented completly and not tested well and not yet documented.>

IO::Socket::SSL class in L<SPVM> has methods for SSL sockets.

=head1 Usage

  use IO::Socket::SSL;

=head1 Details



=head1 Super Class



=head1 Interfaces



=head1 Enumerations



=head1 Fields



=head1 Class Methods



=head1 Instance Methods



=head1 See Also




=head1 Repository



=head1 Author

Yuki Kimoto C<kimoto.yuki@gmail.com>

=head1 Copyright & License

Copyright (c) 2024 Yuki Kimoto

MIT License

